/*
  Copyright (C) 2000-2003  Taiga Yonekura, taiga@col.hi-ho.ne.jp

  For more information about this appliation please look at:
   http://www.pat.hi-ho.ne.jp/kyonekura

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#ifndef COMMON_H
#define COMMON_H

#include "myGtk.h"
#include "config.h"


#define BLOCK_NONE       0
#define BLOCK_STOPPER 0xFF       

#define VALUE_MAX       0xFFFFFF

#define FIRST_PLAYER     1   
#define SECOND_PLAYER    2   

#define TAIGA    1
#define PENPEN   2
#define TAKU     3

#define ENEMY_COUNT 2


typedef struct{
  gint player;      
  gint value;       
  gint posx;        
  gint posy;        
} MtrxValue;

typedef struct{
  gint totalval;                       
  MtrxValue valueobj;                  
  void  *nextnode[BLOCK_NUM_X];
} MtrxLinkNode;

#endif
